# XMelange

Python library for working with xml, xsd, wsdl and soap web services

## Installation

```$ pip install xmelange```

## Run from command line

## Complex Types
Complex types allow elements in their content (via `<xsd:sequence>` and `<xsd:element>`)
Complex types also can carry attributes (via `<xsd:attributes>`).

## Simple Types
Simple types cannot have element content.
Simple types cannot carry attributes.
